complete -c topgrade -l disable -d 'Do not perform upgrades for the given steps' -r -f -a "{am	'',android_studio	'',app_man	'',aqua	'',asdf	'',atom	'',audit	'',auto_cpufreq	'',bin	'',bob	'',brew_cask	'',brew_formula	'',bun	'',bun_packages	'',cargo	'',certbot	'',chezmoi	'',chocolatey	'',choosenim	'',cinnamon_spices	'',clam_av_db	'',composer	'',conda	'',config_update	'',containers	'',custom_commands	'',deb_get	'',deno	'',distrobox	'',dkp_pacman	'',dotnet	'',elan	'',emacs	'',firmware	'',flatpak	'',flutter	'',fossil	'',gcloud	'',gem	'',ghcup	'',git_repos	'',github_cli_extensions	'',gnome_shell_extensions	'',go	'',guix	'',haxelib	'',helix	'',helm	'',home_manager	'',jetbrains_aqua	'',jetbrains_clion	'',jetbrains_datagrip	'',jetbrains_dataspell	'',jetbrains_gateway	'',jetbrains_goland	'',jetbrains_idea	'',jetbrains_mps	'',jetbrains_phpstorm	'',jetbrains_pycharm	'',jetbrains_rider	'',jetbrains_rubymine	'',jetbrains_rustrover	'',jetbrains_toolbox	'',jetbrains_webstorm	'',jetpack	'',julia	'',juliaup	'',kakoune	'',krew	'',lensfun	'',lure	'',macports	'',mamba	'',mas	'',maza	'',micro	'',microsoft_store	'',miktex	'',mise	'',myrepos	'',nix	'',node	'',opam	'',pacdef	'',pacstall	'',pearl	'',pip3	'',pip_review	'',pip_review_local	'',pipupgrade	'',pipx	'',pipxu	'',pixi	'',pkg	'',pkgin	'',platformio_core	'',pnpm	'',poetry	'',powershell	'',protonup	'',pyenv	'',raco	'',rcm	'',remotes	'',restarts	'',rtcl	'',ruby_gems	'',rustup	'',rye	'',scoop	'',sdkman	'',self_update	'',sheldon	'',shell	'',snap	'',sparkle	'',spicetify	'',stack	'',stew	'',system	'',tldr	'',tlmgr	'',tmux	'',toolbx	'',uv	'',vagrant	'',vcpkg	'',vim	'',volta_packages	'',vscode	'',vscodium	'',waydroid	'',winget	'',wsl	'',wsl_update	'',xcodes	'',yadm	'',yarn	'',yazi	'',zigup	'',zvm	''}"
complete -c topgrade -l only -d 'Perform only the specified steps' -r -f -a "{am	'',android_studio	'',app_man	'',aqua	'',asdf	'',atom	'',audit	'',auto_cpufreq	'',bin	'',bob	'',brew_cask	'',brew_formula	'',bun	'',bun_packages	'',cargo	'',certbot	'',chezmoi	'',chocolatey	'',choosenim	'',cinnamon_spices	'',clam_av_db	'',composer	'',conda	'',config_update	'',containers	'',custom_commands	'',deb_get	'',deno	'',distrobox	'',dkp_pacman	'',dotnet	'',elan	'',emacs	'',firmware	'',flatpak	'',flutter	'',fossil	'',gcloud	'',gem	'',ghcup	'',git_repos	'',github_cli_extensions	'',gnome_shell_extensions	'',go	'',guix	'',haxelib	'',helix	'',helm	'',home_manager	'',jetbrains_aqua	'',jetbrains_clion	'',jetbrains_datagrip	'',jetbrains_dataspell	'',jetbrains_gateway	'',jetbrains_goland	'',jetbrains_idea	'',jetbrains_mps	'',jetbrains_phpstorm	'',jetbrains_pycharm	'',jetbrains_rider	'',jetbrains_rubymine	'',jetbrains_rustrover	'',jetbrains_toolbox	'',jetbrains_webstorm	'',jetpack	'',julia	'',juliaup	'',kakoune	'',krew	'',lensfun	'',lure	'',macports	'',mamba	'',mas	'',maza	'',micro	'',microsoft_store	'',miktex	'',mise	'',myrepos	'',nix	'',node	'',opam	'',pacdef	'',pacstall	'',pearl	'',pip3	'',pip_review	'',pip_review_local	'',pipupgrade	'',pipx	'',pipxu	'',pixi	'',pkg	'',pkgin	'',platformio_core	'',pnpm	'',poetry	'',powershell	'',protonup	'',pyenv	'',raco	'',rcm	'',remotes	'',restarts	'',rtcl	'',ruby_gems	'',rustup	'',rye	'',scoop	'',sdkman	'',self_update	'',sheldon	'',shell	'',snap	'',sparkle	'',spicetify	'',stack	'',stew	'',system	'',tldr	'',tlmgr	'',tmux	'',toolbx	'',uv	'',vagrant	'',vcpkg	'',vim	'',volta_packages	'',vscode	'',vscodium	'',waydroid	'',winget	'',wsl	'',wsl_update	'',xcodes	'',yadm	'',yarn	'',yazi	'',zigup	'',zvm	''}"
complete -c topgrade -l custom-commands -d 'Run only specific custom commands' -r
complete -c topgrade -l env -d 'Set environment variables' -r
complete -c topgrade -s y -l yes -d 'Say yes to package manager\'s prompt' -r -f -a "{am	'',android_studio	'',app_man	'',aqua	'',asdf	'',atom	'',audit	'',auto_cpufreq	'',bin	'',bob	'',brew_cask	'',brew_formula	'',bun	'',bun_packages	'',cargo	'',certbot	'',chezmoi	'',chocolatey	'',choosenim	'',cinnamon_spices	'',clam_av_db	'',composer	'',conda	'',config_update	'',containers	'',custom_commands	'',deb_get	'',deno	'',distrobox	'',dkp_pacman	'',dotnet	'',elan	'',emacs	'',firmware	'',flatpak	'',flutter	'',fossil	'',gcloud	'',gem	'',ghcup	'',git_repos	'',github_cli_extensions	'',gnome_shell_extensions	'',go	'',guix	'',haxelib	'',helix	'',helm	'',home_manager	'',jetbrains_aqua	'',jetbrains_clion	'',jetbrains_datagrip	'',jetbrains_dataspell	'',jetbrains_gateway	'',jetbrains_goland	'',jetbrains_idea	'',jetbrains_mps	'',jetbrains_phpstorm	'',jetbrains_pycharm	'',jetbrains_rider	'',jetbrains_rubymine	'',jetbrains_rustrover	'',jetbrains_toolbox	'',jetbrains_webstorm	'',jetpack	'',julia	'',juliaup	'',kakoune	'',krew	'',lensfun	'',lure	'',macports	'',mamba	'',mas	'',maza	'',micro	'',microsoft_store	'',miktex	'',mise	'',myrepos	'',nix	'',node	'',opam	'',pacdef	'',pacstall	'',pearl	'',pip3	'',pip_review	'',pip_review_local	'',pipupgrade	'',pipx	'',pipxu	'',pixi	'',pkg	'',pkgin	'',platformio_core	'',pnpm	'',poetry	'',powershell	'',protonup	'',pyenv	'',raco	'',rcm	'',remotes	'',restarts	'',rtcl	'',ruby_gems	'',rustup	'',rye	'',scoop	'',sdkman	'',self_update	'',sheldon	'',shell	'',snap	'',sparkle	'',spicetify	'',stack	'',stew	'',system	'',tldr	'',tlmgr	'',tmux	'',toolbx	'',uv	'',vagrant	'',vcpkg	'',vim	'',volta_packages	'',vscode	'',vscodium	'',waydroid	'',winget	'',wsl	'',wsl_update	'',xcodes	'',yadm	'',yarn	'',yazi	'',zigup	'',zvm	''}"
complete -c topgrade -l config -d 'Alternative configuration file' -r -F
complete -c topgrade -l remote-host-limit -d 'A regular expression for restricting remote host execution' -r
complete -c topgrade -l log-filter -d 'Tracing filter directives' -r
complete -c topgrade -l gen-completion -d 'Print completion script for the given shell and exit' -r -f -a "{bash	'',elvish	'',fish	'',powershell	'',zsh	''}"
complete -c topgrade -l edit-config -d 'Edit the configuration file'
complete -c topgrade -l config-reference -d 'Show config reference'
complete -c topgrade -s t -l tmux -d 'Run inside tmux'
complete -c topgrade -s c -l cleanup -d 'Cleanup temporary or old files'
complete -c topgrade -s n -l dry-run -d 'Print what would be done'
complete -c topgrade -l no-retry -d 'Do not ask to retry failed steps'
complete -c topgrade -s v -l verbose -d 'Output debug logs. Alias for `--log-filter debug`'
complete -c topgrade -s k -l keep -d 'Prompt for a key before exiting'
complete -c topgrade -l skip-notify -d 'Skip sending a notification at the end of a run'
complete -c topgrade -l disable-predefined-git-repos -d 'Don\'t pull the predefined git repos'
complete -c topgrade -l show-skipped -d 'Show the reason for skipped steps'
complete -c topgrade -l gen-manpage -d 'Print roff manpage and exit'
complete -c topgrade -l no-self-update -d 'Don\'t update Topgrade'
complete -c topgrade -s h -l help -d 'Print help (see more with \'--help\')'
complete -c topgrade -s V -l version -d 'Print version'
